package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcBudgetCarMapper;
import com.ruoyi.oa.domain.CmcBudgetCar;
import com.ruoyi.oa.service.ICmcBudgetCarService;

/**
 * cmc车辆预算Service业务层处理
 * 
 * @author cmc
 * @date 2024-03-22
 */
@Service
public class CmcBudgetCarServiceImpl implements ICmcBudgetCarService 
{
    @Autowired
    private CmcBudgetCarMapper cmcBudgetCarMapper;

    /**
     * 查询cmc车辆预算
     * 
     * @param budgetId cmc预算id
     * @return cmc车辆预算
     */
    @Override
    public List<CmcBudgetCar> selectCmcBudgetCarByBudgetId(String budgetId)
    {
        return cmcBudgetCarMapper.selectCmcBudgetCarByBudgetId(budgetId);
    }

    /**
     * 查询cmc车辆预算列表
     * 
     * @param cmcBudgetCar cmc车辆预算
     * @return cmc车辆预算
     */
    @Override
    public List<CmcBudgetCar> selectCmcBudgetCarList(CmcBudgetCar cmcBudgetCar)
    {
        return cmcBudgetCarMapper.selectCmcBudgetCarList(cmcBudgetCar);
    }

    /**
     * 新增cmc车辆预算
     * 
     * @param cmcBudgetCar cmc车辆预算
     * @return 结果
     */
    @Override
    public int insertCmcBudgetCar(CmcBudgetCar cmcBudgetCar)
    {
        return cmcBudgetCarMapper.insertCmcBudgetCar(cmcBudgetCar);
    }

    /**
     * 修改cmc车辆预算
     * 
     * @param cmcBudgetCar cmc车辆预算
     * @return 结果
     */
    @Override
    public int updateCmcBudgetCar(CmcBudgetCar cmcBudgetCar)
    {
        return cmcBudgetCarMapper.updateCmcBudgetCar(cmcBudgetCar);
    }

    /**
     * 批量删除cmc车辆预算
     * 
     * @param budgetIds 需要删除的cmc车辆预算主键
     * @return 结果
     */
    @Override
    public int deleteCmcBudgetCarByBudgetIds(String[] budgetIds)
    {
        return cmcBudgetCarMapper.deleteCmcBudgetCarByBudgetIds(budgetIds);
    }

    /**
     * 删除cmc车辆预算信息
     * 
     * @param budgetId cmc车辆预算主键
     * @return 结果
     */
    @Override
    public int deleteCmcBudgetCarByBudgetId(String budgetId)
    {
        return cmcBudgetCarMapper.deleteCmcBudgetCarByBudgetId(budgetId);
    }
}
